@@ -280,17 +280,6 @@ static int Main()
 #endif /* RLIMIT_STACK */
 	}
 
-	/* Calculate additional global constants. */
-	ScriptGlobal::Set("System.PlatformKernel", Utility::GetPlatformKernel(), true);
-	ScriptGlobal::Set("System.PlatformKernelVersion", Utility::GetPlatformKernelVersion(), true);
-	ScriptGlobal::Set("System.PlatformName", Utility::GetPlatformName(), true);
-	ScriptGlobal::Set("System.PlatformVersion", Utility::GetPlatformVersion(), true);
-	ScriptGlobal::Set("System.PlatformArchitecture", Utility::GetPlatformArchitecture(), true);
-
-	ScriptGlobal::Set("System.BuildHostName", ICINGA_BUILD_HOST_NAME, true);
-	ScriptGlobal::Set("System.BuildCompilerName", ICINGA_BUILD_COMPILER_NAME, true);
-	ScriptGlobal::Set("System.BuildCompilerVersion", ICINGA_BUILD_COMPILER_VERSION, true);
-
 	if (!autocomplete)
 		Application::SetResourceLimits();
 
@@ -412,7 +401,7 @@ static int Main()
 #endif /* _WIN32 */
 
 	if (vm.count("define")) {
-		for (const String& define : vm["define"].as<std::vector<std::string> >()) {
+		for (String define : vm["define"].as<std::vector<std::string>>()) {
 			String key, value;
 			size_t pos = define.FindFirstOf('=');
 			if (pos != String::NPos) {
@@ -438,13 +427,24 @@ static int Main()
 			std::unique_ptr<SetExpression> setExpr{new SetExpression(std::move(expr), OpSetLiteral, MakeLiteral(value))};
 			setExpr->SetOverrideFrozen();
 
-			ScriptFrame frame(true);
-			setExpr->Evaluate(frame);
+			try {
+				ScriptFrame frame(true);
+				setExpr->Evaluate(frame);
+			} catch (const ScriptError& e) {
+				Log(LogCritical, "icinga-app") << "cannot set '" << key << "': " << e.what();
+				return EXIT_FAILURE;
+			}
 		}
 	}
 
 	Configuration::SetReadOnly(true);
 
+	if (!Configuration::ConcurrencyWasModified) {
+		Configuration::Concurrency = std::thread::hardware_concurrency();
+	}
+
+	Application::GetTP().Restart();
+
 	/* Ensure that all defined constants work in the way we expect them. */
 	HandleLegacyDefines();
 
@@ -460,7 +460,7 @@ static int Main()
 	ConfigCompiler::AddIncludeSearchDir(Configuration::IncludeConfDir);
 
 	if (!autocomplete && vm.count("include")) {
-		for (const String& includePath : vm["include"].as<std::vector<std::string> >()) {
+		for (String includePath : vm["include"].as<std::vector<std::string>>()) {
 			ConfigCompiler::AddIncludeSearchDir(includePath);
 		}
 	}
