@@ -4,10 +4,14 @@
 #define APPLICATION_H
 
 #include "base/i2-base.hpp"
+#include "base/atomic.hpp"
 #include "base/application-ti.hpp"
 #include "base/logger.hpp"
 #include "base/configuration.hpp"
+#include "base/shared-memory.hpp"
+#include <cstdint>
 #include <iosfwd>
+#include <type_traits>
 
 namespace icinga
 {
@@ -137,7 +141,13 @@ private:
 	static double m_StartTime;
 	static double m_MainTime;
 	static bool m_ScriptDebuggerEnabled;
+#ifdef _WIN32
 	static double m_LastReloadFailed;
+#else /* _WIN32 */
+	typedef Atomic<std::conditional_t<Atomic<double>::is_always_lock_free, double, uint32_t>> AtomicTs;
+	static_assert(AtomicTs::is_always_lock_free);
+	static SharedMemory<AtomicTs> m_LastReloadFailed;
+#endif /* _WIN32 */
 
 #ifdef _WIN32
 	static BOOL WINAPI CtrlHandler(DWORD type);
